@@ -27,7 +27,7 @@ if __name__ == '__main__':
         'action',
         const='generate',
         nargs='?',
-        choices=['list', 'create', 'describe', 'deploy']
+        choices=['init', 'list', 'create', 'describe', 'deploy']
     )
     parser_endpoint.add_argument('endpoint', const='generate', nargs='?')
     parser_endpoint.set_defaults(which='endpoints')
