@@ -147,8 +147,13 @@ pyyaml
 
 
 def job_main():
-    return """if __name__ == "__main__":
+    return """from shopcloud_serverless import Environment
+
+if __name__ == "__main__":
+    env = Environment()
+    print(env.get('ENV'))
     print("Hello World")
+
 """
 
 
