@@ -145,9 +145,15 @@ def cli_main(args, config: Config):
                 f'{config.base_dir}/jobs/{job_name}/Procfile',
                 file_contents.job_procfile(),
             ),
+            steps.StepCreateFile(
+                f'{config.base_dir}/jobs/{job_name}/requirements.in',
+                """shopcloud-serverless
+""",
+            ),
             steps.StepCreateFile(
                 f'{config.base_dir}/jobs/{job_name}/requirements.txt',
-                "",
+                """shopcloud-serverless
+"""
             ),
             steps.StepCreateFile(
                 f'{config.base_dir}/jobs/{job_name}/.env.temp',
