@@ -63,7 +63,7 @@ class StepCopyFileContent(Step):
 
 
 class StepAppendFileContent(Step):
-    def __init__(self, file_path: str, content: str):
+    def __init__(self, file_path: str, content: List[str]):
         self.file_path = file_path
         self.content = content
 
@@ -73,6 +73,17 @@ class StepAppendFileContent(Step):
             f.write("\n".join(self.content))
 
 
+class StepCreateFile(Step):
+    def __init__(self, file_path: str, content: str):
+        self.file_path = file_path
+        self.content = content
+
+    def run(self, config: Config, simulate: bool = False):
+        print(f'+ Append to {self.file_path}')
+        with open(self.file_path, "w") as f:
+            f.write(self.content)
+
+
 class StepCopyDir(Step):
     def __init__(self, path_a: str, path_b: str):
         self.path_a = path_a
@@ -87,14 +98,16 @@ class StepCommand(Step):
     def __init__(self, command: List[str], **kwargs):
         self.command = command
         self.work_dir = kwargs.get('work_dir')
+        self.can_fail = kwargs.get('can_fail', False)
 
     def run(self, config: Config, simulate: bool = False):
         print('+ Run command:')
         print(" ".join(self.command))
         if not simulate:
             p = subprocess.run(self.command, stdout=subprocess.PIPE, cwd=self.work_dir)
-            if p.returncode != 0:
-                raise exceptions.CommandError('command not success')
+            if not self.can_fail:
+                if p.returncode != 0:
+                    raise exceptions.CommandError('command not success')
 
 
 class Manager:
